import React, { useRef, useEffect, useState } from 'react'
import ThreeScene from '../../ar_tool/components/threejsScene';
import { SceneHolder } from '../../ar_tool/components/sceneHolder';

import './visualization-compare.scss';

const VisualizationCompare = ({ onSelect, onFullScreen }) => {
  const threeSceneRefs = useRef([]);
  const [imgOptions, setImgOptions] = useState();
  let uiOptionsEventCount = 0;
  const combinedObject = {}

  const compareCallback = (index, handler) => {
    threeSceneRefs.current[index] = handler;
  }
  const onPlayAnimation = (type, status) => {
    threeSceneRefs.current.forEach((handler, index) => {
      handler.playAnimation(type, status);
    });

  }

  const resetZoomHandler = () => {
    threeSceneRefs.current.forEach((handler, index) => {
      handler.resetZoom();
    });
  }

  const zoomHandler = (type) => {
    threeSceneRefs.current.forEach((handler, index) => {
      handler.zoom(type);
    });

  }

  const scaleYHandler = (type) => {
    threeSceneRefs.current.forEach((handler, index) => {
      handler.scaleNegativeYAxis(type);
    });
  }


  const scaleXHandler = (type) => {
    threeSceneRefs.current.forEach((handler, index) => {
      handler.scaleXAxis(type);
    });
  }

  const getUIOptions = () => {
    threeSceneRefs.current.forEach((handler, index) => {
      for (const key in handler.configObj) {
        combinedObject[key] = combinedObject[key] || handler.configObj[key];
      }
    });
    console.log(combinedObject);
    setImgOptions(combinedObject)
  }

  useEffect(() => {
    threeSceneRefs.current.forEach((handler, index) => {
      handler.addEventListener('uiOptions', event => {
        uiOptionsEventCount++;
        if (uiOptionsEventCount === threeSceneRefs.current.length) {
          getUIOptions();
          uiOptionsEventCount = 0;
        }
    });
    });
  }, [threeSceneRefs]);


  return (
    <>
      <div className={`compare-container`}>
        {SceneHolder.sceneList.length > 0 &&
          SceneHolder.sceneList.map((item, index) => (
            <div key={index} className="flex-1 bg-yellow-500">
              <ThreeScene index={index} hideOptions={true} callback={compareCallback} sceneObj={item} />
            </div>
          ))}

        <div className='blind-controls'>
          <div className="blind-container">

            <button className=" btn-transparent" onClick={() => { onPlayAnimation("open", true) }}>
              <img alt="" src="https://visualization.graberblinds.com/assets/graphics/window-control-horizontal-open.svg" />
            </button>

            <button className=" btn-transparent" onClick={() => { onPlayAnimation("open", false) }}>
              <img alt="" src="https://visualization.graberblinds.com/assets/graphics/window-control-horizontal-close.svg" />
            </button>

            {imgOptions?.foldIn && (
              <>
                <button
                  className=' btn-transparent'
                  onClick={() => onPlayAnimation('fold', true)}
                >
                  <img
                    alt=''
                    src='https://visualization.graberblinds.com/assets/graphics/window-control-horizontal-tilt-open.svg'
                  />
                </button>

                <button
                  className=' btn-transparent'
                  onClick={() => onPlayAnimation('fold', false)}
                >
                  <img
                    alt=''
                    src='https://visualization.graberblinds.com/assets/graphics/window-control-horizontal-tilt-close.svg'
                  />
                </button>
             </>
            )}

            { SceneHolder.sceneList.some(obj => obj.productName === 'Draperies')  && <> 
            <button className=' btn-transparent' onClick={() => scaleXHandler(true)}  >
              <img alt='' src='https://visualization.graberblinds.com/assets/graphics/window-extend-wider.svg'  />
            </button>

            <button className=' btn-transparent' onClick={() => scaleXHandler(false)} >
              <img alt='' src='https://visualization.graberblinds.com/assets/graphics/window-extend-narrower.svg'/>
            </button>

            <button className=' btn-transparent' onClick={() => scaleYHandler(true)} >
              <img alt=''  src='https://visualization.graberblinds.com/assets/graphics/window-extend-higher.svg'/> 
            </button>

            <button className=' btn-transparent' onClick={() => scaleYHandler(false)} >
              <img alt='' src='https://visualization.graberblinds.com/assets/graphics/window-extend-lower.svg' />
            </button>
           </> }
          </div>

          <div className='blind-container m-l-10'>
            <button
              className=' btn-transparent'
              onClick={() => resetZoomHandler()}
            >
              <img
                alt=''
                src='https://visualization.graberblinds.com/assets/graphics/2021_zoom_reset.svg'
              />
            </button>

            <button
              className=' btn-transparent'
              onClick={() => zoomHandler(false)}
            >
              <img
                alt=''
                src='https://visualization.graberblinds.com/assets/graphics/2021_zoom_out.svg'
              />
            </button>
            <button
              className=' btn-transparent'
              onClick={() => zoomHandler(true)}
            >
              <img
                alt=''
                src='https://visualization.graberblinds.com/assets/graphics/2021_zoom_in.svg'
              />
            </button>

            <button className=' btn-transparent full-screen' onClick={onFullScreen}>
              <img
                alt=''
                src='https://visualization.graberblinds.com/assets/graphics/2021_fullscreen.svg'
              />
            </button>
          </div>



        </div>
      </div>
    </>
  )
}

export default VisualizationCompare
