import React, { useState, useEffect, useCallback } from 'react';
import { useDispatch, useSelector } from 'react-redux';
import { Image } from 'react-bootstrap';
// import { modalObj } from '@services/shades-module';
import Loader from '../../../../shared/loader/loader';
import { getEndpointBaseURL } from '@services/environment';
import { updateSavedProject } from '@store/actions/saved-project-actions';
import { getSceneHandler } from '@store/actions/saved-scene-actions';
import { fetchProductsAPIData } from '@store/actions/products-api-actions';
import './product.scss';

const Products = React.memo(() => {
  const dispatch = useDispatch();
  const sceneDispatch = useDispatch();

  const productsData = useSelector((state) => state.productsAPIData);
  const savedSceneDetails = useSelector((state) => state.savedScene);
  const sampleRoomDetails = useSelector((state) => state.savedProjects.sampleRoom);
  const defaultProduct = useSelector((state) => state.savedProjects.defaultProduct);

  const [activeProduct, setActiveProduct] = useState('');

  useEffect(() => {
    if (productsData?.products?.length === 0) {
      dispatch(fetchProductsAPIData(`${getEndpointBaseURL()}products`));
    }
  }, []);

  const handleClick = useCallback((imageItem) => {
    try {
      setActiveProduct(imageItem.id);
      dispatch(updateSavedProject(imageItem));
      sceneDispatch(getSceneHandler());
      if (savedSceneDetails.currentScene &&imageItem.ar_model_url) {
         savedSceneDetails.currentScene.changeBlind(imageItem.ar_model_url);
      }
    } catch (error) {
      console.error('Error handling click:', error);
    }
  }, [dispatch, sceneDispatch, savedSceneDetails]);

  useEffect(() => {

    if (sampleRoomDetails && !defaultProduct) {
      const defaultProductId = sampleRoomDetails['default_product_id'];
      const selectedImageItem = productsData?.products?.find((imageItem) => imageItem?.id === defaultProductId);
      setActiveProduct(defaultProductId);
      selectedImageItem && dispatch(updateSavedProject(selectedImageItem));
    } 

    if (defaultProduct) {
      const defaultProductId = defaultProduct['id'];
      setActiveProduct(defaultProductId);
    }
  }, [productsData]);

  return (
    <div className='product-container'>
      {productsData.loading ? (
        <Loader />
      ) : (
        <ul className='side-img'>
          {productsData?.products?.map((imageItem) => (
            <li key={imageItem.id}>
              <span className='product-image-container'>
                <Image
                  src={imageItem.product_image_path}
                  onClick={() => handleClick(imageItem)}
                  className={activeProduct === imageItem.id ? 'active' : ''}
                />
              </span>
              <p>{imageItem.product_name}</p>
            </li>
          ))}
        </ul>
      )}
    </div>
  );
});

export default Products;
